@@ -5,10 +5,7 @@ def infos(target, arg):
     target.deploy('.infos')
 
 def add(target, arg):
-    try:
-        target.modules.add(arg)
-    except Exception as x:
-        print(x)
+    target.modules.add(arg)
 
 def deploy(target, arg):
     target.deploy(arg)
