@@ -36,6 +36,9 @@ class Dnf(Packager):
     def do_update(self):
         self.run('dnf update -y')
 
+    def do_upgrade(self):
+        self.run('dnf upgrade -y')
+
     def do_install(self, pkg, ver=None):
         ver = f' ={ver}' if ver else ''
         ret, out, err = self.run(f'dnf -y -C install {pkg}{ver}')
